# :book: folktexts   <!-- omit in toc -->
> :construction: Package under construction

![Tests status](https://github.com/AndreFCruz/folktexts/actions/workflows/python-package.yml/badge.svg)
![PyPI status](https://github.com/AndreFCruz/folktexts/actions/workflows/python-publish.yml/badge.svg)
![Documentation status](https://github.com/AndreFCruz/folktexts/actions/workflows/python-docs.yml/badge.svg)
![PyPI version](https://badgen.net/pypi/v/folktexts)
![OSI license](https://badgen.net/pypi/license/folktexts)
![Python compatibility](https://badgen.net/pypi/python/folktexts)

Repo to host the `folktexts` project.

Package documentation can be found [here](https://andrefcruz.github.io/folktexts/)!

**Table of contents:**
- [Installing](#installing)
- [Usage](#usage)
- [License and terms of use](#license-and-terms-of-use)


## Installing

Install package from [PyPI](https://pypi.org/project/folktexts/):

```
pip install folktexts
```


## Usage

*TODO*


## License and terms of use

*TODO* (data is licensed under CC BY-NC-SA 4.0; `folktexts` code can be licensed under MIT)
